import http from "http";
import https from "https";
import url from "url";
import querystring from "querystring";

const redirectStatus = new Set([ 301, 302, 303, 307, 308 ]);

const readdata = (res, mode, data = "") => new Promise((resolve, reject) => res
  .setEncoding("utf8")
  .on("data", chunk => data += chunk)
  .on("end", () => {
    switch(mode) {
      case "text":   resolve(data); break;
      case "json":   try { resolve(JSON.parse(data)); } catch(err) { reject(data); } break;
      case "buffer": resolve(new Buffer.from(data)); break;
      default:       reject("lol no D:"); break;
    }
  }));
const genResolve = res => ({
  body:    res,
  headers: res.headers,
  text:    () => readdata(res, "text"),
  json:    () => readdata(res, "json"),
  buffer:  () => readdata(res, "buffer")
});
const request = (a, options, resolve, reject, link = url.parse(a), body = "") => {
  options = {...{ hostname: link.hostname, path: link.path, method: "GET", redirect: "follow" }, ...options};
  if(options.method === "POST") {
    body = typeof options.body === "object" ? querystring.stringify(options.body) : options.body;
    delete options.body;
    options.headers = {...options.headers, ...{
      "Content-Type":   "application/x-www-form-urlencoded",
      "Content-Length": Buffer.byteLength(body)
    }};
  }
  (link.protocol === "https:"?https:http).request(options, res => {
    if(redirectStatus.has(res.statusCode) || options.redirect === "manual") {
      switch(options.redirect) {
        case "follow":
          delete options.hostname;
          delete options.path;
          request(res.headers.location.startsWith("http") ? res.headers.location : `${link.protocol}//${link.host}${res.headers.location}`, options, resolve, reject);
        break;
        case "error": return reject("error lol");
      }
    }
    else return resolve(genResolve(res));
  }).on("error", err => err).end(body);
};
export default (_url, options = {}) => new Promise((resolve, reject) => request(_url, options, resolve, reject));
