import fetch from "./lib/fetch.mjs";

const api = {
  mankier: "https://www.mankier.com/api/v2/mans/?q=",
  arch: "https://man.archlinux.org/man/"
};

export default async bot => {
  return [{
    name: "man",
    call: /^(\.|\/)man .*/i,
    f: async e => {
      let section = 0
        , search = e.args[0]
        , lang = "en";

      if(e.args.length > 1)
        [ search, section ] = [ e.args[1], e.args[0] ];
      if(e.args.length > 2)
        lang = e.args[2];

      const mankier = await (await fetch(`${api.mankier}${search}${section > 0 ? `&sections=${section}` : ""}`)).json();
      if(mankier.results.length === 0)
        return e.reply("nothing found lol");

      if(e.args[0] === "search") {
        return e.reply(
          mankier.results.flatMap(m => `[b]${m.name}.${m.section}[/b]: [i]${m.description}[/i]`)
        );
      }

      try {
        const man = await fetch(`${api.arch}${search}${section > 0 ? `.${section}` : ""}.${lang}`);
        const title = man.body.req.path;
        const mantext = (await man.text()).match(/<section class=\"Sh\">(.*?)<\/section>/gsm);
      
        // 0 name, 1 synopsis, 2 description
      
        const name = mantext[0].split("\n").slice(2, -1).join("\n");
        const descr = mantext[2]
          .replace(/<p.*/gsm, "")
          .split("\n").slice(2, -1).join("\n")
          .replace(/<([\/]?)(b|i)>/g, "[$1$2]")
          .replace(/<.*?>/g, "");

        return e.reply([
          descr, `https://man.archlinux.org${title}`
        ]);
      } catch(e) {
        return e.reply("nope lol");
      }
    }
  }]
};

//const api = "https://www.mankier.com/api/v2/mans/?q=";
//
//export default async bot => {
//  return [{
//    name: "man",
//    call: /^(\.|\/)man .*/i,
//    f: async e => {
//      let section = 0
//        , search = e.args[0];
//
//      if(e.args.length > 1)
//        [ search, section ] = [ e.args[1], e.args[0] ];
//
//      const man = await (await fetch(`${api}${search}${section > 0 ? `&sections=${section}` : ""}`)).json();
//      if(man.results.length === 0)
//        return e.reply("nothing found lol");
//
//      if(e.args[0] === "search") {
//        return e.reply(
//          man.results.flatMap(m => `[b]${m.name}.${m.section}[/b]: [i]${m.description}[/i]`)
//        );
//      }
//
//      return e.reply([
//        `[b]${man.results[0].name}[/b], section [b]${man.results[0].section}[/b]`,
//        `[i]${man.results[0].description}[/i]`,
//        `${man.results[0].url}`
//      ]);
//    }
//  }]
//};
